package com.muyu.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.muyu.domain.model.ActivityTeamInfoAddModel;
import com.muyu.domain.model.ActivityTeamInfoSaveModel;
import com.muyu.domain.model.ActivityTeamInfoUpdModel;
import com.muyu.domain.req.ActivityTeamInfoSaveReq;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;

@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor

public class ActivityTeamInfo {


  /**
   * 主键
   */
  @TableId(value = "id", type = IdType.AUTO)
  private long id;
  /**
   * 拼团名称
   */
  private String name;
  /**
   * 商品ID
   */
  private long productId;
  /**
   * 商品活动图
   */
  private String productImage;
  /**
   * 活动简介
   */
  private String introduction;
  /**
   * 单位
   */
  private String unit;
  /**
   * 轮播图
   */
  private String imageList;
  /**
   * 活动结束时间
   */
  private Date endTime;
  /**
   * 活动排序
   */
  private long sort;
  /**
   * 活动详情
   */
  private String content;
  /**
   * 活动状态
   */
  private String status;
  /**
   * 策略类型
   */
  private String strategyType;
  /**
   * 策略ID
   */
  private long strategyId;

  /**
   * 公共添加模型，转换成添加对象
   * @param activityTeamInfoAddModel 添加模型
   * @return 添加对象
   */
  public static ActivityTeamInfo addModelBuild(ActivityTeamInfoAddModel activityTeamInfoAddModel){
    return ActivityTeamInfo.builder()
            .name(activityTeamInfoAddModel.getName())
            .productId(activityTeamInfoAddModel.getProductId())
            .productImage(activityTeamInfoAddModel.getProductImage())
            .introduction(activityTeamInfoAddModel.getIntroduction())
            .unit(activityTeamInfoAddModel.getUnit())
            .imageList(activityTeamInfoAddModel.getImageList())
            .endTime(activityTeamInfoAddModel.getEndTime())
            .sort(activityTeamInfoAddModel.getSort())
            .content(activityTeamInfoAddModel.getContent())
            .status(activityTeamInfoAddModel.getStatus())
            .strategyType(activityTeamInfoAddModel.getStrategyType())
            .strategyId(activityTeamInfoAddModel.getStrategyId())
            .build();
  }
  public static ActivityTeamInfo buildModel(ActivityTeamInfoSaveReq activityTeamInfoSaveReq){
    String images = activityTeamInfoSaveReq.getImageList().toString();
    return ActivityTeamInfo.builder()
            .productId(activityTeamInfoSaveReq.getProjectId())
            .productImage(activityTeamInfoSaveReq.getProjectImage())
            .unit(activityTeamInfoSaveReq.getUnit())
            .imageList(images)
            .name(activityTeamInfoSaveReq.getName())
            .introduction(activityTeamInfoSaveReq.getIntroduction())
            .endTime(activityTeamInfoSaveReq.getEndTime())
            .strategyId(activityTeamInfoSaveReq.getStrategyId())
            .strategyType(activityTeamInfoSaveReq.getStrategyType())
            .sort(activityTeamInfoSaveReq.getSort())
            .build();
  }

  public static ActivityTeamInfo teamSaveBuild(ActivityTeamInfoSaveModel activityTeamInfoSaveModel) {
    return ActivityTeamInfo.builder()
            .name(activityTeamInfoSaveModel.getName())
            .productId(activityTeamInfoSaveModel.getProductId())
            .productImage(activityTeamInfoSaveModel.getProductImage())
            .introduction(activityTeamInfoSaveModel.getIntroduction())
            .unit(activityTeamInfoSaveModel.getUnit())
            .imageList(activityTeamInfoSaveModel.getImageList())
            .endTime(activityTeamInfoSaveModel.getEndTime())
            .sort(activityTeamInfoSaveModel.getSort())
            .content(activityTeamInfoSaveModel.getContent())
            .status(activityTeamInfoSaveModel.getStatus())
            .strategyType(activityTeamInfoSaveModel.getStrategyType())
            .strategyId(activityTeamInfoSaveModel.getStrategyId())
            .build();
  }
  public static ActivityTeamInfo TeamUpdateBuild (ActivityTeamInfoUpdModel activityTeamInfoUpdModel){
    return ActivityTeamInfo.builder()
            .id(activityTeamInfoUpdModel.getId())
            .name(activityTeamInfoUpdModel.getName())
            .productId(activityTeamInfoUpdModel.getProductId())
            .productImage(activityTeamInfoUpdModel.getProductImage())
            .introduction(activityTeamInfoUpdModel.getIntroduction())
            .unit(activityTeamInfoUpdModel.getUnit())
            .imageList(activityTeamInfoUpdModel.getImageList())
            .endTime(activityTeamInfoUpdModel.getEndTime())
            .sort(activityTeamInfoUpdModel.getSort())
            .content(activityTeamInfoUpdModel.getContent())
            .status(activityTeamInfoUpdModel.getStatus())
            .strategyType(activityTeamInfoUpdModel.getStrategyType())
            .strategyId(activityTeamInfoUpdModel.getStrategyId())
            .build();
  }
}
