package com.muyu.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.muyu.domain.model.ActivityTeamProductSkuAddModel;
import com.muyu.domain.model.ActivityTeamProductSkuReqModel;
import com.muyu.domain.model.ActivityTeamProductSkuUpdModel;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;

@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class ActivityTeamProductSkuInfo {
  /**
   * 主键
   */
  @TableId(value = "id", type = IdType.AUTO)
  private long id;
  /**
   * 活动ID
   */
  private long teamId;
  /**
   * 商品ID
   */
  private Long productId;
  /**
   * 商品SKU
   */
  private String productSku;
  /**
   * 拼团库存
   */
  private Long teamStock;
  /**
   * 剩余库存
   */
  private Long remainStock;
  /**
   * 拼团价格
   */
  private BigDecimal teamPrice;

  /**
   * 通过模型钢构件对象
   * @param activityTeamProductSkuAddModel 模型
   * @return 对象
   */
  public static ActivityTeamProductSkuInfo modelBuild(ActivityTeamProductSkuAddModel activityTeamProductSkuAddModel) {
    return ActivityTeamProductSkuInfo.builder()
            .productId(activityTeamProductSkuAddModel.getProductId())
            .teamId(activityTeamProductSkuAddModel.getTeamId())
            .teamStock(activityTeamProductSkuAddModel.getTeamStock())
            .productSku(activityTeamProductSkuAddModel.getSku())
            .remainStock(activityTeamProductSkuAddModel.getTeamStock())
            .teamPrice(activityTeamProductSkuAddModel.getTeamPrice())
            .build();
  }
  public static ActivityTeamProductSkuInfo updateModelBuild(ActivityTeamProductSkuReqModel activityTeamProductSkuReqModel) {
    return ActivityTeamProductSkuInfo.builder()
            .id(activityTeamProductSkuReqModel.getId())
            .productId(activityTeamProductSkuReqModel.getProductId())
            .teamStock(activityTeamProductSkuReqModel.getTeamStock())
            .productSku(activityTeamProductSkuReqModel.getProductSku())
            .teamPrice(activityTeamProductSkuReqModel.getTeamPrice())
            .build();
  }

  public static ActivityTeamProductSkuInfo updModelBuild(ActivityTeamProductSkuUpdModel teamProductSkuUpdModel){
    return ActivityTeamProductSkuInfo.builder()
            .id(teamProductSkuUpdModel.getId())
            .teamPrice(teamProductSkuUpdModel.getTeamPrice())
            .teamStock(teamProductSkuUpdModel.getTeamStock())
            .remainStock(teamProductSkuUpdModel.getTeamStock())
            .build();
  }

}
