package com.muyu.system.team.controller;


import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.dtflys.forest.annotation.Post;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.domain.ActivityTeamInfo;
import com.muyu.domain.model.ActivitySkuModel;
import com.muyu.domain.model.ActivityTeamInfoAddModel;
import com.muyu.domain.model.ActivityTeamInfoListModel;
import com.muyu.domain.model.ActivityTeamInfoUpdModel;
import com.muyu.domain.req.ActivityInfoAddReq;
import com.muyu.domain.req.ActivityTeamInfoSaveReq;
import com.muyu.domain.req.ActivityTeamInfoUpdReq;
import com.muyu.domain.req.TeamInfoListReq;
import com.muyu.domain.resp.TeamInfoFindByIdResp;
import com.muyu.domain.resp.TeamInfoListResp;
import com.muyu.system.team.service.ActivityTeamInfoService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.text.ParseException;
import java.util.List;

/**
 * 商品拼团信息
 * @program: cloud-server
 * @description: 商品拼团信息
 * @author: CuiFu Bo
 * @create: 2024-11-20 21:49
 **/

@RestController
@RequestMapping("/team")
public class ActivityTeamInfoController {

    @Resource
    private ActivityTeamInfoService activityTeamInfoService;

    /**
     * 团购活动列表查询
     * @param teamInfoListReq 分页
     * @return 列表数据
     */
    @RequiresPermissions("marketing:marketing:list")
    @PostMapping("/list")
    public Result<TableDataInfo<TeamInfoListResp>> list(@RequestBody TeamInfoListReq teamInfoListReq){
        TableDataInfo<ActivityTeamInfoListModel> tableDataInfo = activityTeamInfoService.query(teamInfoListReq.buildQueryModel());
        List<TeamInfoListResp> listResp = tableDataInfo.getRows().stream().map(TeamInfoListResp::listModerBuild).toList();
        return Result.success(
                new TableDataInfo<>(){{
                    setRows(listResp);
                    setTotal(tableDataInfo.getTotal());
                }}
        );
    }

    /**
     * 新增团购活动
     * @param activityTeamInfoSaveReq 团购参数
     * @return
     */
    @RequiresPermissions("marketing:marketing:save")
    @PostMapping("/save")
    public Result<String> save(@RequestBody ActivityTeamInfoSaveReq activityTeamInfoSaveReq ) throws ParseException {
        return activityTeamInfoService.save(activityTeamInfoSaveReq);
    }

    @PostMapping("/findById/{id}")
    public Result<TeamInfoFindByIdResp> findTeamById(@PathVariable Long id){
        return Result.success(TeamInfoFindByIdResp.teamInfoFindByIdBuild(activityTeamInfoService.findDetailById(id)));
    }
    @PutMapping("/updateByTeamId")
    public Result updateByTeamId(@RequestBody ActivityTeamInfoUpdReq activityTeamInfoUpdReq){
        activityTeamInfoService.update(ActivityTeamInfoUpdModel.activityTeamInfoUpdReqModelBuild(activityTeamInfoUpdReq));
        return Result.success();
    }

    /**
     * 根据ID查询详情
     * @param id 活动I D
     * @return 活动详情
     */
    @GetMapping("/teamList/{id}")
    public Result<List<ActivityTeamInfo>> teamList(@PathVariable("id") Long id){
        List<ActivityTeamInfo> activityTeamInfoList= activityTeamInfoService.teamList(id);
        return Result.success(activityTeamInfoList);
    }

}
