package com.muyu.system.team.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.domain.ActivityTeamInfo;
import com.muyu.domain.ActivityTeamProductSkuInfo;
import com.muyu.domain.model.*;
import com.muyu.domain.req.ActivityInfoSkuAddReq;
import com.muyu.domain.req.ActivityTeamInfoSaveReq;
import com.muyu.system.team.mapper.ActivityTeamInfoMapper;
import com.muyu.system.team.service.ActivityTeamInfoService;
import com.muyu.system.team.service.ActivityTeamOpenInfoService;
import com.muyu.system.team.service.ActivityTeamProductSkuInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.Assert;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 商品拼团信息
 * @author: CuiFu Bo
 * @create: 2024-11-20 21:39
 **/

@Service
public class ActivityTeamInfoServiceImpl extends ServiceImpl<ActivityTeamInfoMapper, ActivityTeamInfo> implements ActivityTeamInfoService {
    @Resource
    private ActivityTeamOpenInfoService activityTeamOpenInfoService;
    @Resource
    private ActivityTeamProductSkuInfoService activityTeamProductSkuInfoService;
    @Override
    public TableDataInfo<ActivityTeamInfoListModel> query(ActivityTeamInfoListQueryModel activityTeamInfoListQueryModel) {
        Page<ActivityTeamInfo> page = new Page<>();

        LambdaQueryWrapper<ActivityTeamInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.like(StringUtils.isNotEmpty(activityTeamInfoListQueryModel.getKeyWord()),ActivityTeamInfo::getName,activityTeamInfoListQueryModel.getKeyWord());
        queryWrapper.like(StringUtils.isNotEmpty(activityTeamInfoListQueryModel.getStatus()),ActivityTeamInfo::getStatus,activityTeamInfoListQueryModel.getStatus());


        Page<ActivityTeamInfo> activityTeamInfoPage = this.page(activityTeamInfoListQueryModel.bulidPage(), queryWrapper);
        List<ActivityTeamInfo> activityTeamInfoList = activityTeamInfoPage.getRecords();
        List<ActivityTeamInfoListModel> infoListModels = activityTeamInfoList.stream().map(
                activityTeamInfo -> ActivityTeamInfoListModel.infoBuild(activityTeamInfo,
                        (activityTeamInfoListModelBuilder) -> {
                            TeamDiscountPriceModel discountPrice = activityTeamProductSkuInfoService.getDiscountPrice(activityTeamInfo.getId());
                            TeamProductStockModel productStockModer = activityTeamProductSkuInfoService.getStock(activityTeamInfo.getId());
                            Long teamOpenTypeByOpenTeam = activityTeamOpenInfoService.getTeamOpenTypeByOpenAndTypeTeam(activityTeamInfo.getId());
                            Long teamOpenTypeByInTeam = activityTeamOpenInfoService.getTeamOpenTypeByInAndTypeTeam(activityTeamInfo.getId());
                            return activityTeamInfoListModelBuilder
                                    .addTeamNumber(teamOpenTypeByInTeam)
                                    .openTeamNumber(teamOpenTypeByOpenTeam)
                                    .attendNumber(teamOpenTypeByInTeam + teamOpenTypeByOpenTeam)
                                    .teamPrice(discountPrice.getTeamPrice())
                                    .teamStock(productStockModer.getTeamStock())
                                    .remainStock(productStockModer.getRemainStock())
                                    .build();
                        })).toList();
                        TableDataInfo<ActivityTeamInfoListModel> tableDataInfo = new TableDataInfo<>();
                        tableDataInfo.setTotal(activityTeamInfoPage.getTotal());
                        tableDataInfo.setRows(infoListModels);
                        return tableDataInfo;

    }


    /**
     * 添加拼团活动
     * @param
     * @param
     */
    @Override
    @Transactional
    public Result<String> save(ActivityTeamInfoSaveReq activityTeamInfoSaveReq) {
        ActivityTeamInfo activityTeamInfo = ActivityTeamInfo.buildModel(activityTeamInfoSaveReq);
        //添加返回主键ID
        Assert.isTrue(this.save(activityTeamInfo),StringUtils.format("添加商品拼团错误",activityTeamInfoSaveReq));
        List<ActivityInfoSkuAddReq> projectSkuList = activityTeamInfoSaveReq.getTeamProjectSkuInfoAddReqList();

        List<ActivityTeamProductSkuInfo> teamProductSkuInfoList = projectSkuList.stream().map(projectSkuModel -> {
                    return ActivityTeamProductSkuInfo.builder()
                            .teamId(activityTeamInfo.getId())
                            .productId(activityTeamInfo.getProductId())
                            .productSku(projectSkuModel.getProductSku())
                            .teamStock(Long.valueOf(projectSkuModel.getTeamStock()))
                            .remainStock(Long.valueOf(projectSkuModel.getTeamStock()))
                            .teamPrice(projectSkuModel.getTeamPrice())
                            .build();
                })
                .filter(Objects::nonNull) // 过滤掉null值
                .collect(Collectors.toList());

        activityTeamProductSkuInfoService.saveBatch(teamProductSkuInfoList);
        return Result.success();
    }
    /**
     * 根据ID查询商品的详情
     * @param id 团购活动ID
     * @return 团购详情
     */
    @Override
    public ActivityTeamDetailModel findDetailById(Long id) {
        ActivityTeamInfo activityTeamInfo = this.getById(id);
        List<ActivityTeamProductSkuModel> activityTeamProductSkuModelList = activityTeamProductSkuInfoService.findListByTeamId(id);
        return ActivityTeamDetailModel.findSkuSumList(activityTeamInfo,
                (teamInfoFindByIdRespModelBuilder) -> teamInfoFindByIdRespModelBuilder.projectSkuInfoAddReqList(activityTeamProductSkuModelList).build()
        );
    }

    /**
     * 修改团购活动信息
     * @param activityTeamInfoUpdModel 团购活动信息
     * @return 是否成功
     */
    @Override
    public boolean update(ActivityTeamInfoUpdModel activityTeamInfoUpdModel) {
        boolean update = this.updateById(ActivityTeamInfo.TeamUpdateBuild(activityTeamInfoUpdModel));
        Assert.isTrue(update,"修改失败");
        activityTeamProductSkuInfoService.setting(activityTeamInfoUpdModel.getActivityTeamProductSkuSettingModel());
        return update;
    }

    /**
     * 根据ID查询详情
     * @param id 活动ID
     * @return 查询详情
     */
    @Override
    public List<ActivityTeamInfo> teamList(Long id) {
        LambdaQueryWrapper<ActivityTeamInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(ActivityTeamInfo::getId,id);
        List<ActivityTeamInfo> list = this.list(queryWrapper);
        return list;
    }

}

